pub struct Action {
pub commands: Option<Vec<String>>,
pub timeout_ms: Option<i32>,
}Expand description
An Action encapsulates a set of commands as a single runnable module with additional information needed during run-time.
This type is not used in any activity, and only used as part of another schema.
Fields
commands: Option<Vec<String>>A list of commands to run sequentially for this action.
timeout_ms: Option<i32>The timeout in milliseconds for this action to run.