pub struct Deployment {
pub creation_date: Option<String>,
pub description: Option<String>,
pub modules: Option<HashMap<String, ModuleStatus>>,
pub name: Option<String>,
pub overrides: Option<Vec<ParamOverride>>,
pub state: Option<DeployState>,
pub template_name: Option<String>,
}Expand description
A deployment represents a physical instantiation of a Template.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- delete deployments (none)
- get deployments (response)
- insert deployments (request|response)
- list deployments (none)
Fields
creation_date: Option<String>[Output Only] The time when this deployment was created.
description: Option<String>A user-supplied description of this Deployment.
modules: Option<HashMap<String, ModuleStatus>>[Output Only] List of status for the modules in this deployment.
name: Option<String>Name of this deployment. The name must conform to the following regular expression: [a-zA-Z0-9-_]{1,64}
overrides: Option<Vec<ParamOverride>>The set of parameter overrides to apply to the corresponding Template before deploying.
state: Option<DeployState>[Output Only] Current status of this deployment.
template_name: Option<String>The name of the Template on which this deployment is based.