pub struct DiskAttachment {
pub device_name: Option<String>,
pub index: Option<u32>,
}Expand description
How to attach a disk to a Replica.
This type is not used in any activity, and only used as part of another schema.
Fields
device_name: Option<String>The device name of this disk.
index: Option<u32>A zero-based index to assign to this disk, where 0 is reserved for the boot disk. If not specified, this is assigned by the server.