ExistingDisk

Struct ExistingDisk 

pub struct ExistingDisk {
    pub attachment: Option<DiskAttachment>,
    pub source: Option<String>,
}
A pre-existing persistent disk that will be attached to every Replica in the Pool.

This type is not used in any activity, and only used as part of another schema.

Fields

attachment: Option<DiskAttachment>

Optional. How the disk will be attached to the Replica.

source: Option<String>

The fully-qualified URL of the Persistent Disk resource. It must be in the same zone as the Pool.