pub struct Module {
pub autoscaling_module: Option<AutoscalingModule>,
pub firewall_module: Option<FirewallModule>,
pub health_check_module: Option<HealthCheckModule>,
pub lb_module: Option<LbModule>,
pub network_module: Option<NetworkModule>,
pub replica_pool_module: Option<ReplicaPoolModule>,
pub type_: Option<String>,
}Expand description
A module in a configuration. A module represents a single homogeneous, possibly replicated task.
This type is not used in any activity, and only used as part of another schema.
Fields
autoscaling_module: Option<AutoscalingModule>no description provided
firewall_module: Option<FirewallModule>no description provided
health_check_module: Option<HealthCheckModule>no description provided
lb_module: Option<LbModule>no description provided
network_module: Option<NetworkModule>no description provided
replica_pool_module: Option<ReplicaPoolModule>no description provided
type_: Option<String>The type of this module. Valid values (“AUTOSCALING”, “FIREWALL”, “HEALTH_CHECK”, “LOAD_BALANCING”, “NETWORK”, “REPLICA_POOL”)