pub struct NetworkInterface {
pub access_configs: Option<Vec<AccessConfig>>,
pub name: Option<String>,
pub network: Option<String>,
pub network_ip: Option<String>,
}Expand description
A Compute Engine NetworkInterface resource. Identical to the NetworkInterface on the corresponding Compute Engine resource.
This type is not used in any activity, and only used as part of another schema.
Fields
access_configs: Option<Vec<AccessConfig>>An array of configurations for this interface. This specifies how this interface is configured to interact with other network services
name: Option<String>Name of the interface.
network: Option<String>The name of the NetworkModule to which this interface applies. If not specified, or specified as ‘default’, this will use the ‘default’ network.
network_ip: Option<String>An optional IPV4 internal network address to assign to the instance for this network interface.