pub struct NewDisk {
pub attachment: Option<DiskAttachment>,
pub auto_delete: Option<bool>,
pub boot: Option<bool>,
pub initialize_params: Option<NewDiskInitializeParams>,
}Expand description
A Persistent Disk resource that will be created and attached to each Replica in the Pool. Each Replica will have a unique persistent disk that is created and attached to that Replica.
This type is not used in any activity, and only used as part of another schema.
Fields
attachment: Option<DiskAttachment>How the disk will be attached to the Replica.
auto_delete: Option<bool>If true, then this disk will be deleted when the instance is deleted.
boot: Option<bool>If true, indicates that this is the root persistent disk.
initialize_params: Option<NewDiskInitializeParams>Create the new disk using these parameters. The name of the disk will be <instance_name>-<five_random_charactersgt;.