pub struct ReplicaPoolModuleStatus {
pub replica_pool_url: Option<String>,
pub resource_view_url: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
replica_pool_url: Option<String>[Output Only] The URL of the associated ReplicaPool resource.
resource_view_url: Option<String>[Output Only] The URL of the Resource Group associated with this ReplicaPool.