pub struct ServiceAccount {
pub email: Option<String>,
pub scopes: Option<Vec<String>>,
}Expand description
A Compute Engine service account, identical to the Compute Engine resource.
This type is not used in any activity, and only used as part of another schema.
Fields
email: Option<String>Service account email address.
scopes: Option<Vec<String>>List of OAuth2 scopes to obtain for the service account.