pub struct Tag {
pub finger_print: Option<String>,
pub items: Option<Vec<String>>,
}Expand description
A Compute Engine Instance tag, identical to the tags on the corresponding Compute Engine Instance resource.
This type is not used in any activity, and only used as part of another schema.
Fields
finger_print: Option<String>The fingerprint of the tag.
items: Option<Vec<String>>Items contained in this tag.