pub struct TemplatesListResponse {
pub next_page_token: Option<String>,
pub resources: Option<Vec<Template>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list templates (response)
Fields
next_page_token: Option<String>no description provided
resources: Option<Vec<Template>>no description provided